@@ -1,4 +1,3 @@
-import pprint
 from collections.abc import Mapping
 
 import sqlalchemy as sa
@@ -6,6 +5,7 @@ import sqlalchemy as sa
 from alembic.migration import MigrationContext
 from alembic.autogenerate import produce_migrations
 from alembic.autogenerate import render_python_code
+from alembic.util.exc import CommandError
 
 from sqlalchemy.sql.schema import DefaultClause
 from sqlalchemy.sql.elements import TextClause
@@ -213,9 +213,15 @@ class Runner(object):
         # migration_script = produce_migrations(self.mc, self.metadata)
         # print(render_python_code(migration_script.upgrade_ops))
 
-        # TODO we need a top level upgrade path which is run when we get to production instead of running this
-        # we need to only call upgrade() and not revision() and then upgrade()
-        self.revision(diff)
+        try:
+            self.revision(diff)
+        except CommandError as err:
+            # expected when not up to date so let's make it up to date by upgrading
+            if str(err) == "Target database is not up to date.":
+                pass
+            else:
+                raise err
+
         self.upgrade()
 
     def revision_message(self, diff=None):
@@ -298,8 +304,29 @@ class Runner(object):
         # understand diff and make changes as needed
         # pprint.pprint(migrations, indent=2, width=30)
 
-    def upgrade(self):
-        self.cmd.upgrade()
+    def upgrade(self, revision='head'):
+        self.cmd.upgrade(revision)
 
     def downgrade(self, revision):
         self.cmd.downgrade(revision)
+
+    def history(self):
+        self.cmd.history()
+    
+    def current(self):
+        self.cmd.current()
+
+    def show(self, revision):
+        self.cmd.show(revision)
+
+    def heads(self):
+        self.cmd.heads()
+
+    def branches(self):
+        self.cmd.branches()
+
+    def stamp(self, revision):
+        self.cmd.stamp(revision)
+
+    def edit(self, revision):
+        self.cmd.edit(revision)
